* groff_handbook_2020_multilevel_006_REVISED
* BRINGS IN ORIGINAL DATA FILE
* DOES BASIC FILE PROCESSING
* GENERATES VARIABLES AND RUNS FOR MULTILEVEL CHAPTER
**************************************************************************
* SET UP COMMANDS - START
clear all
macro drop _all
set autotabgraphs on
set more off
capture log close _all
set linesize 150
translator set smcl2pdf tmargin 0.3
translator set smcl2pdf bmargin 0.3
translator set smcl2pdf rmargin 0.3
translator set smcl2pdf lmargin 0.5
translator set smcl2pdf fontsize 7
cls
* SET UP COMMANDS - END
**************************************************************************
* Setting working directory and starting log file
cd "C:\PCW5\groff_2020\ICPSR_02371\DS0002"
log using groff_handbook_2020_multilevel_006_REVISED.log, replace
cd "C:\PCW5\groff_2020\ICPSR_02371\DS0002"
**************************************************************************


***********************
*  FIXING MISSING VALUES IN ORIGINAL ICPSR DATA FILE AFTE CONVERTING TO STATA
* START
***********************
* bring in beh obs data file
clear all
use "C:\PCW5\groff_2020\ICPSR_02371\DS0002\MSP_BEH_OBS_DS0002.dta"

tolower CENTERCO-MAXGROUP

describe
summ

* cleaning up missing values

recode nthpersn(99=.)
tab nthpersn, missing

recode grpsize (99=.)
tab grpsize, missing

tab1 sex-bususe1, missing
tab1 sex-bususe1, missing nolabel

recode sex-bususe1 (9=.)
tab1 sex-bususe1, missing

* saving file with missing values fixed
save msp_beh_obs_v_bb.dta, replace

***********************
*  FIXING MISSING VALUES IN ORIGINAL ICPSR DATA FILE AFTE CONVERTING TO STATA
* END
***********************

***********************
* bringing in the file that already has missing values fixed
* additional data processing
* BEGIN
***********************
clear all
use msp_beh_obs_v_bb.dta

summ
describe

***
* make a white dummy variable
gen whitedum=0
replace whitedum=1 if(race==0)
replace whitedum=. if(race==.)
tab whitedum race, missing
label var whitedum "1 = white pedestrian 0 = other"

***
* make a kid or teen pedestrian dummy variable
gen kidrteen=0
replace kidrteen=1 if(age<=1) 
replace kidrteen=1 if age==.
tab kidrteen age, missing nolabel
label var kidrteen "1 = kid or teen 0 = other"

***
* looking at the raw relationship
* in table form
tab primbiz kidrteen, col lrchi

***
* some additional variables

* centerco is the place variable - level 2 identifier
* going to sort on that
sort centerco

* create a kidrteen variable that is just the commercial center averages
* this is just the level 2 variation in this predictor
by centerco: egen x_kidrteen=mean(kidrteen)
label var x_kidrteen "SCC level proportion kid/teen pedestrians"

***
* creating a centered version of x_kidrteen
center x_kidrteen
label var c_x_kidrteen "overall centered version of SCC means on kidrteen" 

* create a curvilinear component of ecological kidrteen
gen sq_x_kidrteen=c_x_kidrteen*c_x_kidrteen
label var sq_x_kidrteen  "squared proportion teens at SCC level"
corr sq_x_kidrteen c_x_kidrteen
graph twoway (scatter sq_x_kidrteen c_x_kidrteen)  (lfit sq_x_kidrteen c_x_kidrteen)

* level 2 variation in the outcome
* creating a level 2 variable
by centerco: egen x_primbiz=mean(primbiz)
label var x_primbiz "SCC level proportion pedestrians using a business or service"

* create a kidrteen variable reflecting just within center variation
* this is just the level 1 variation in this predictor
by centerco: center kidrteen, gen(wi_kidrteen)
label var wi_kidrteen "within center variation kidrteen"

* do same for primbiz
* this is just the level 1 variation in this outcome
by centerco: center primbiz, gen(wi_primbiz)
label var wi_primbiz "within center variation primbiz"

***
* look at descriptives for the two variables
* raw form level 2 form level 1 form
statsmat primbiz kidrteen x_primbiz x_kidrteen wi_primbiz wi_kidrteen, st(n min max mean sd)

***
* save updated unit level file
save msp_beh_obs_v_dd.dta, replace

***********************
* additional data processing
* END
***********************

***********************
* CREATING AN ECOLOGICAL FILE COLLAPSED TO THE SMALL COMMERCIAL CENTERS
* START
***********************

collapse (mean) x_alone=alone x_whited=whitedum ///
		x_prbiz=primbiz ///
		x_child=child ///
		x_teen=teen ///
		x_kidrteen=kidrteen ///
	(sd) sd_alone=alone sd_whited=whitedum /// 
	sd_prbiz=primbiz ///
	, by(centerco)

label var x_prbiz "center mean proportion primarily business users"
label var x_child "center mean proportion children"
label var x_teen "center mean proportion teens"
label var x_kidrteen	"center mean proportion teens or children"

* save collapsed file
save msp_beh_obs_v_dd_collapse.dta, replace

* add one more varuiabke to collapsed file and then re save
clear all
use msp_beh_obs_v_dd_collapse.dta, replace
* going to create a group mean centered version of * center level kidrteen
sort centerco
by centerco: center x_kidrteen
label var c_x_kidrteen "center level centered kidrteen - by commerical area" 

* now create squared version of scc centered kidrteen
gen sq_kidrteen=c_x_kidrteen*c_x_kidrteen
label var sq_kidrteen "squared scc level centered kidrteen"
graph twoway scatter  sq_kidrteen c_x_kidrteen

* save
save msp_beh_obs_v_ee_collapse.dta, replace

***********************
* CREATING AN ECOLOGICAL FILE COLLAPSED TO THE SMALL COMMERCIAL CENTERS
* END
***********************

***********************
* merge collapsed SCC level file and unit level file
* START
***********************
clear all
use msp_beh_obs_v_dd.dta
* do merge
merge m:1 centerco using msp_beh_obs_v_ee_collapse.dta

* save merged file
notes: v dd has center mean and sd variables on some things
save msp_beh_obs_v_ee.dta, replace

***********************
* merge collapsed SCC level file and unit level file
* END
***********************

***********************
* looking at bivariate relationships
*	at both pedestrian and center level
* 	between key predictor - child or teen pedestrian
*	and key outcome - primarily business user
* START
***********************

* look at pedestrian level link between kidrteen and primbiz
clear all
use msp_beh_obs_v_ee.dta
tab primbiz kidrteen, col lrchi

* let's look at center level connection between kidrteen and primbiz
clear all
use  msp_beh_obs_v_ee_collapse.dta, replace
sort x_kidrteen
list x_kidrteen centerco
tab centerco, nolabel
tab centerco
list x_kidrteen if(centerco!=990)

* level 2  SCC level relationship
* all SCCs
graph twoway (lowess x_prbiz x_kidrteen) || (scatter x_prbiz x_kidrteen)|| (qfit x_prbiz x_kidrteen )
graph save x_prbiz_x_kidrteen.gph, replace

* same graph without 38th and 4th
graph twoway (lowess x_prbiz x_kidrteen) || (scatter x_prbiz x_kidrteen)|| (qfit x_prbiz x_kidrteen ) if(centerco!=990)
graph save x_prbiz_x_kidrteen_lt_minus_990.gph, replace

***********************
* looking at bivariate relationships
*	at both pedestrian and center level
* 	between key predictor - child or teen pedestrian
*	and key outcome - primarily business user
* END
***********************

*********************************************************************************
*
*
* 	ON TO THE MONOLEVEL AND MIXED MODELS
*
* THE REST OF THIS DO FILE IS FOR CHAPTER 8.4 ON MULTILEVEL MODELS
*
*
*********************************************************************************

***********************
* descriptives
* 	look at descriptives for the two variables
* 	raw form level 2 form level 1 form
* begin
***********************

clear all
use msp_beh_obs_v_ee.dta
statsmat primbiz kidrteen x_primbiz x_kidrteen wi_primbiz wi_kidrteen, st(n min max mean sd)

***********************
* descriptives
* 	look at descriptives for the two variables
* 	raw form level 2 form level 1 form
* end
***********************

***********************
* ANOVA model
* begin
***********************
***
*		monolevel
logit primbiz , or

***
*		mixed effects
melogit primbiz || centerco: , or

***
* getting a measure of lack of fit
estat ic

***
* getting proportion of outcome at level 2
estat icc

***
* now predicting eb means for primbiz at commercial center level
predict pred_biz 
label var pred_biz "eb_mean_predicted prim_biz"

***
* graph eb means prim_biz versus center means
* shows eb adjustments
graph bar x_primbiz pred_biz, over(centerco, sort(1))
graph save bar_x_prim_biz_pred_biz.gph, replace
*
* went in and made adjustments to graph
*
* saved as revised
* appears in text
*
***
* getting descriptive statistics on raw and EB adjusted means
summ x_primbiz pred_biz

***
* saving the file
notes: v ee has predicted outcome score from anova
save msp_beh_obs_v_ee.dta, replace

***********************
* ANOVA model
* end
***********************

***********************
* looking at effects of age mix on primarily business/service user
* begin
***********************
***
* plain logit monolevel
logit primbiz kidrteen, or

***
* multilevel - raw variable
melogit primbiz kidrteen ||centerco: , or

***
* multilevel - level 1 and level 2 impacts separated
melogit primbiz x_kidrteen  wi_kidrteen ||centerco: , or

***
* multilevel - level 1 and level 2 impacts separated
* linear and curvilinear impacts of level 2 kidrteen
melogit primbiz c_x_kidrteen sq_x_kidrteen wi_kidrteen ||centerco: , or
melogit primbiz c_x_kidrteen sq_x_kidrteen wi_kidrteen ||centerco: , 

***********************
* looking at effects of age mix on primarily business/service user
* end
***********************

***********************
* now create a collapsed file with observed and eb mean scores at center level
* begin
***********************

collapse (mean) primbiz pred_biz  kidrteen  ///
	, by(centerco)

* save collapsed file
save msp_beh_obs_v_ff_collapsed.dta, replace
clear all
use msp_beh_obs_v_ff_collapsed.dta

***********************
* now create a collapsed file with observed and eb mean scores at center level
* end
***********************

***********************
* further descriptive examinations
* begin
***********************

***
* list true means and eb adjusted means
sort primbiz
list centerco primbiz pred_biz

* looking at the level-2 relationship between young peds and biz peds.

graph twoway (lowess primbiz kidrteen) || (scatter primbiz kidrteen)|| (qfit primbiz kidrteen ) || (lfit primbiz kidrteen )
graph save x_prbiz_x_kidrteen.gph, replace

* worked on graph to create revised version

***********************
* further descriptive examinations
* end
***********************

log close
exit
*********************************************************


